@@ -160,10 +160,9 @@ gdl_get_activity_from_pointer (GladeDesignLayout *layout, gint x, gint y)
   
   if (priv->selection)
     {
-      priv->margin = gdl_get_margins_from_pointer (gtk_bin_get_child (GTK_BIN (layout)),
+      priv->margin = gdl_get_margins_from_pointer (GTK_WIDGET (layout),
                                                    priv->selection,
-                                                   x - priv->child_offset,
-                                                   y - priv->child_offset);
+                                                   x, y);
       
       if (priv->margin)
         {
@@ -1448,22 +1447,8 @@ glade_design_layout_draw (GtkWidget *widget, cairo_t *cr)
         {
           gint border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
           gboolean selected = FALSE;
-          gint w, h;
           GList *l;
 
-          w = gdk_window_get_width (window);
-          h = gdk_window_get_height (window);
-
-          cairo_save (cr);
-          cairo_rectangle (cr, 0, 0, priv->child_offset, h);
-          cairo_rectangle (cr, 0, 0, w, priv->child_offset);
-          cairo_rectangle (cr, 0, priv->south_east.y, w, priv->south_east.height);
-          cairo_rectangle (cr, w-priv->child_offset, 0, priv->child_offset, h);
-          cairo_clip (cr);
-          gtk_render_background (gtk_widget_get_style_context (widget),
-                                 cr, 0, 0, w, h);
-          cairo_restore (cr);
-
           /* draw offscreen widgets */
           gdk_cairo_set_source_window (cr, priv->offscreen_window,
                                        priv->child_offset, priv->child_offset);
@@ -1592,6 +1577,29 @@ offscreen_window_from_parent (GdkWindow     *window,
   to_child (bin, parent_x, parent_y, offscreen_x, offscreen_y);
 }
 
+static void
+glade_design_layout_offscreen_bg_update (GladeDesignLayoutPrivate *priv)
+{
+  GtkStyleContext *context;
+  GtkWidgetPath *path;
+  GdkRGBA color;
+
+  if (!priv->offscreen_window)
+    return;
+
+  context = gtk_style_context_new ();
+  path = gtk_widget_path_new ();
+
+  gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
+  gtk_style_context_set_path (context, path);
+  gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &color);
+
+  gdk_window_set_background_rgba (priv->offscreen_window, &color);
+
+  gtk_widget_path_unref (path);
+  g_object_unref (context);
+}
+
 static void
 glade_design_layout_realize (GtkWidget * widget)
 {
@@ -1683,6 +1691,8 @@ glade_design_layout_realize (GtkWidget * widget)
   priv->cursors[ACTIVITY_MARGINS_BOTTOM_RIGHT] = g_object_ref (priv->cursors[ACTIVITY_RESIZE_WIDTH_AND_HEIGHT]);
   
   priv->widget_name = pango_layout_new (gtk_widget_get_pango_context (widget));
+
+  glade_design_layout_offscreen_bg_update (priv);
 }
 
 static void
@@ -1745,15 +1755,16 @@ static void
 glade_design_layout_style_updated (GtkWidget *widget)
 {
   GladeDesignLayoutPrivate *priv = GLADE_DESIGN_LAYOUT_GET_PRIVATE (widget);
-  GtkStyleContext *context = gtk_widget_get_style_context (widget);
-
-  _glade_design_layout_get_colors (context,
+  
+  _glade_design_layout_get_colors (gtk_widget_get_style_context (widget),
                                    &priv->frame_color[0],
                                    &priv->frame_color[1],
                                    &priv->frame_color_active[0],
                                    &priv->frame_color_active[1]);
 
   priv->fg_color = priv->frame_color[1];
+
+  glade_design_layout_offscreen_bg_update (priv);
 }
 
 static void
@@ -2040,6 +2051,31 @@ _glade_design_layout_draw_pushpin (cairo_t *cr,
   cairo_restore (cr);
 }
 
+static inline void
+_glade_design_layout_coords_from_event (GdkWindow *parent,
+                                        GdkEvent *event,
+                                        gint *x, gint *y)
+{
+  GdkWindow *child = event->any.window;
+  gdouble xx, yy;
+
+  if (!gdk_event_get_coords (event, &xx, &yy))
+    {
+      *x = *y = 0;
+      g_warning ("wrong event type %d", event->type);
+      return;
+    }
+  
+  while (child && parent != child)
+    {
+      gdk_window_coords_to_parent (child, xx, yy, &xx, &yy);
+      child = gdk_window_get_parent (child);
+    }
+
+  *x = xx;
+  *y = yy;
+}
+
 /*
  * _glade_design_layout_do_event:
  * @layout: A #GladeDesignLayout
@@ -2053,31 +2089,23 @@ _glade_design_layout_draw_pushpin (cairo_t *cr,
 gboolean
 _glade_design_layout_do_event (GladeDesignLayout *layout, GdkEvent *event)
 {
-  GladeFindInContainerData data = { 0, };
+  GtkWidget *widget = GTK_WIDGET (layout);
+  GladeFindInContainerData data = { widget, 0, };
   GladeDesignLayoutPrivate *priv;
-  GdkDevice *device;
-  GtkWidget *child;
   gboolean retval;
   GList *l;
-  
-  if ((child = gtk_bin_get_child (GTK_BIN (layout))) == NULL)
-    return FALSE;
 
   priv = GLADE_DESIGN_LAYOUT_GET_PRIVATE (layout);
 
-  if (!(device = glade_widget_get_device_from_event (event))) return FALSE;
-
-  data.toplevel = GTK_WIDGET (child);
-  gdk_window_get_device_position (gtk_widget_get_window (child),
-                                  device, &data.x, &data.y, NULL);
+  _glade_design_layout_coords_from_event (priv->window, event, &data.x, &data.y);
 
   /* Check if we want to enter in margin edit mode */
   if (event->type == GDK_BUTTON_PRESS && event->button.button == 1 &&
       (l = glade_project_selection_get (priv->project)) &&
       g_list_next (l) == NULL && GTK_IS_WIDGET (l->data) && 
-      gtk_widget_is_ancestor (l->data, child))
+      gtk_widget_is_ancestor (l->data, widget))
     {
-      if (gdl_get_margins_from_pointer (child, l->data, data.x, data.y))
+      if (gdl_get_margins_from_pointer (widget, l->data, data.x, data.y))
         {
           if (priv->selection == NULL)
             {
@@ -2092,8 +2120,8 @@ _glade_design_layout_do_event (GladeDesignLayout *layout, GdkEvent *event)
     }
 
   _glade_design_view_freeze (priv->view);
-  
-  glade_design_layout_find_inside_container (child, &data);
+
+  glade_design_layout_find_inside_container (widget, &data);
   
   /* Try the placeholder first */
   if (data.placeholder && gtk_widget_event (data.placeholder, event)) 
